@@ -8,22 +8,22 @@ longer will match the sequence refered to by the other row attributes!
 usage: %prog < maf > maf
 """
 
-import psyco_full
-
 import sys
 
-import sys
 from bx import align
 
+
 def __main__():
 
-    maf_reader = align.maf.Reader( sys.stdin )
-    maf_writer = align.maf.Writer( sys.stdout )
+    maf_reader = align.maf.Reader(sys.stdin)
+    maf_writer = align.maf.Writer(sys.stdout)
 
     for m in maf_reader:
-    
-        align.shuffle_columns( m )
 
-        maf_writer.write( m )
+        align.shuffle_columns(m)
 
-if __name__ == "__main__": __main__()
+        maf_writer.write(m)
+
+
+if __name__ == "__main__":
+    __main__()
