@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-For each block in a maf file (read from stdin) write a sequence of ints 
+For each block in a maf file (read from stdin) write a sequence of ints
 corresponding to the columns of the block after applying the provided sequence
 mapping.
 
@@ -12,31 +12,30 @@ usage: %prog mapping_file
 """
 from __future__ import division, print_function
 
-import string
 import sys
 
 import bx.align.maf
-import psyco_full
 from bx import seqmapping
 
 
 def main():
 
-    if len( sys.argv ) > 1:
-        _, alpha_map = seqmapping.alignment_mapping_from_file( file( sys.argv[1] ) )
+    if len(sys.argv) > 1:
+        _, alpha_map = seqmapping.alignment_mapping_from_file(open(sys.argv[1]))
     else:
         alpha_map = None
 
-    for maf in bx.align.maf.Reader( sys.stdin ):
+    for maf in bx.align.maf.Reader(sys.stdin):
         # Translate alignment to ints
-        int_seq = seqmapping.DNA.translate_list( [ c.text for c in maf.components ] )
-        # Apply mapping 
+        int_seq = seqmapping.DNA.translate_list([c.text for c in maf.components])
+        # Apply mapping
         if alpha_map:
-            int_seq = alpha_map.translate( int_seq )
+            int_seq = alpha_map.translate(int_seq)
         # Write ints separated by spaces
         for i in int_seq:
             print(i, end=' ')
         print()
 
+
 if __name__ == "__main__":
     main()
